@@ -18,7 +18,11 @@ class YamlAssistant(assistant_base.AssistantBase):
         """Returns kwargs possibly updated with values from .devassistant
         file, when appropriate."""
         if self.role == 'modifier':
-            kwargs.update(run_command('dda_r', kwargs.get('path', '.'), **kwargs))
+            # don't rewrite old values
+            # first get the new ones and then update them with the old
+            new_kwargs = run_command('dda_r', kwargs.get('path', '.'), **kwargs)
+            new_kwargs.update(kwargs)
+            kwargs = new_kwargs
         return kwargs
 
     def logging(self, **kwargs):
@@ -33,7 +37,7 @@ class YamlAssistant(assistant_base.AssistantBase):
                     os.makedirs(os.path.dirname(expanded_lfile))
                 # add handler and formatter
                 handler = logging.FileHandler(expanded_lfile, 'a+')
-                formatter = logging.Formatter('%(asctime)-15s %(levelname)s - %(message)s')
+                formatter = logging.Formatter('%(asctime)-15s [%(event_type)] %(levelname)s - %(message)s')
                 handler.setFormatter(formatter)
                 handler.setLevel(getattr(logging, level.upper()))
                 # register handler with the global logger
@@ -44,10 +48,10 @@ class YamlAssistant(assistant_base.AssistantBase):
     def dependencies(self, **kwargs):
         """Returns all dependencies of this assistant with regards to specified kwargs.
 
-        This is "mapping" of dependency types to actual dependencies
+        This is list of mappings of dependency types to actual dependencies
         (keeps order, types can repeat), e.g.
         Example:
-        [('rpm', ['rubygems']), ('gem', ['mygem']), ('rpm', ['spam']), ...]
+        [{'rpm', ['rubygems']}, {'gem', ['mygem']}, {'rpm', ['spam']}, ...]
         """
 
         kwargs = self.proper_kwargs(**kwargs)
@@ -67,38 +71,61 @@ class YamlAssistant(assistant_base.AssistantBase):
         deps = []
 
         for sect in sections:
-            deps.extend(self._dependencies_section(sect))
+            deps.extend(self._dependencies_section(sect, **kwargs))
 
         return deps
 
     def _dependencies_section(self, section, **kwargs):
         # "deps" is the same structure as gets returned by "dependencies" method
+        execute_else = False
         deps = []
 
-        for dep in section:
-            dep_type, dep_list = dep.popitem()
-            # rpm dependencies (can't handle anything else yet)
-            if dep_type == 'snippet':
-                snippet, section_name = self._get_snippet_and_section_name(dep_list, **kwargs)
-                section = snippet.get_dependencies_section(section_name) if snippet else None
-                if section:
-                    deps.extend(self._dependencies_section(section, **kwargs))
+        for i, dep in enumerate(section):
+            for dep_type, dep_list in dep.items():
+                # rpm dependencies (can't handle anything else yet)
+                if dep_type == 'call':
+                    section = self._get_section_from_call(dep_list, 'dependencies', **kwargs)
+                    if section is not None:
+                        deps.extend(self._dependencies_section(section, **kwargs))
+                    else:
+                        logger.warning('Couldn\'t find dependencies section "{0}", in snippet {1}, skipping.'.format(dep_list.split('.')))
+                elif dep_type in ['rpm']: # handle known types of deps the same, just by appending to "deps" list
+                    deps.append({dep_type: dep_list})
+                ### TODO: this is not completely DRY, the conditionals here use completely the same logic as in run sections
+                elif dep_type.startswith('if'):
+                    if self._evaluate(dep_type[2:].strip(), **kwargs)[0]:
+                        deps.extend(self._dependencies_section(dep_list, **kwargs))
+                    elif len(section) > i + 1:
+                        next_section_dict = section[i + 1]
+                        next_section_dep_type, next_section_dep = list(next_section_dict.items())[0]
+                        if next_section_dep_type == 'else':
+                            execute_else = True
+                elif dep_type == 'else':
+                    # else on its own means error, otherwise execute it
+                    if not list(section[i - 1].items())[0][0].startswith('if'):
+                        logger.warning('Yaml error: encountered "else" with no associated "if", skipping.')
+                    elif execute_else:
+                        execute_else = False
+                        deps.extend(self._dependencies_section(dep_list, **kwargs))
                 else:
-                    logger.warning('Couldn\'t find dependencies section "{0}", in snippet {1}, skipping.'.format(section_name,
-                                                                                                                 dep_list.split('(')[0]))
-            elif dep_type in ['rpm']: # handle known types of deps the same, just by appending to "deps" list
-                deps.append((dep_type, dep_list))
-            else:
-                logger.warning('Unknown dependency type {0}, skipping.'.format(dep_type))
+                    logger.warning('Unknown dependency type {0}, skipping.'.format(dep_type))
 
         return deps
 
     def run(self, **kwargs):
         kwargs = self.proper_kwargs(**kwargs)
         if self.role == 'modifier':
-            to_run = self._get_section_to_run(section='run_{0}'.format('_'.join(kwargs['subassistant_path'])),
-                                              kwargs_override=True,
-                                              **kwargs)
+            # try to get a section to run from the most specialized one to the least specialized one
+            # e.g. first run_python_django, then run_python and then just run
+            for i in range(len(kwargs['subassistant_path']), -1, -1):
+                path = '_'.join(kwargs['subassistant_path'][0:i])
+                if path:
+                    path = '_' + path
+                to_run = self._get_section_to_run(section='run{path}'.format(path=path),
+                                                  kwargs_override=True,
+                                                  **kwargs)
+                if to_run:
+                    break
         else:
             to_run = self._get_section_to_run(section='run', kwargs_override=True, **kwargs)
         if 'pre_run' in dir(self):
@@ -112,32 +139,32 @@ class YamlAssistant(assistant_base.AssistantBase):
 
         for i, command_dict in enumerate(section):
             for comm_type, comm in command_dict.items():
-                if comm_type.startswith('run'):
-                    s = self._get_section_to_run(section=comm, kwargs_override=False, **kwargs)
-                    # use copy of kwargs, so that local kwargs don't get modified
-                    self._run_one_section(s, copy.deepcopy(kwargs))
-                elif comm_type == 'snippet':
-                    snippet, section_name = self._get_snippet_and_section_name(comm, **kwargs)
-                    # don't shadow "section" variable because we need to access it in sys.excepthook
-                    sect = snippet.get_run_section(section_name) if snippet else None
-                    if sect:
-                        # push and pop snippet's files into kwargs
-                        if '__files__' in kwargs:
-                            kwargs['__files__'].append(snippet.get_files_section())
-                        else:
-                            kwargs['__files__'] = [snippet.get_files_section()]
-                        # use copy of kwargs, so that local kwargs don't get modified
-                        self._run_one_section(sect, copy.deepcopy(kwargs))
-                        kwargs['__files__'].pop()
+                if comm_type.startswith('call'):
+                    # calling workflow:
+                    # 1) get proper run section (either from self or from snippet)
+                    # 2) if running snippet, add its files to kwargs['__files__']
+                    # 3) actually run
+                    # 4) if running snippet, pop its files from kwargs['__files__']
+                    sect = self._get_section_from_call(comm, 'run')
+                    if self._is_snippet_call(comm, **kwargs):
+                        # we're calling a snippet => add files to kwargs
+                        snippet = yaml_snippet_loader.YamlSnippetLoader.get_snippet_by_name(comm.split('.')[0])
+                        if '__files__' not in kwargs:
+                            kwargs['__files__'] = []
+                        kwargs['__files__'].append(snippet.get_files_section())
+
+                    if sect is None:
+                        logger.warning('No section to run: {0}.'.format(comm))
                     else:
-                        logger.warning('Couldn\'t find run section "{0}", in snippet {1} skipping.'.format(section_name,
-                                                                                                           comm.split('(')[0]))
+                        self._run_one_section(sect, copy.deepcopy(kwargs))
+
+                    if self._is_snippet_call(comm, **kwargs):
+                        kwargs['__files__'].pop()
                 elif comm_type.startswith('$'):
                     # intentionally pass kwargs as dict, not as keywords
                     self._assign_variable(comm_type, comm, kwargs)
                 elif comm_type.startswith('if'):
-                    # check returned False (exit code != 0), because if commands succeeds without output, we get empty string
-                    if self._evaluate(comm_type[2:].strip(), **kwargs) != False:
+                    if self._evaluate(comm_type[2:].strip(), **kwargs)[0]:
                         # run with original kwargs, so that they might be changed for code after this if
                         self._run_one_section(comm, kwargs)
                     elif len(section) > i + 1:
@@ -153,9 +180,51 @@ class YamlAssistant(assistant_base.AssistantBase):
                         execute_else = False
                         # run with original kwargs, so that they might be changed for code after this if
                         self._run_one_section(comm, kwargs)
+                elif comm_type.startswith('scl'):
+                    if '__scls__' not in kwargs:
+                        kwargs['__scls__'] = []
+                    # list of lists of scl names
+                    kwargs['__scls__'].append(comm_type.split()[1:])
+                    self._run_one_section(comm, kwargs)
+                    kwargs['__scls__'].pop()
                 else:
                     files = kwargs['__files__'][-1] if kwargs.get('__files__', None) else self._files
-                    run_command(comm_type, CommandFormatter.format(comm, self.template_dir, files, **kwargs), **kwargs)
+                    run_command(comm_type, CommandFormatter.format(comm_type, comm, self.template_dir, files, **kwargs), **kwargs)
+
+    def _is_snippet_call(self, cmd_call, **kwargs):
+        return not (cmd_call == 'self' or cmd_call.startswith('self.'))
+
+    def _get_section_from_call(self, cmd_call, section_type, **kwargs):
+        """Returns a section form call.
+
+        Examples:
+            if section_type == dependencies, then
+              cmd_call == self.dependencies_bar returns content of dependencies_bar from this assistant
+            if section_type == run, then
+              cmd_call == self.run_foo returns run_foo of this assistant
+              cmd_call == eclipse.run_python returns run_python section of eclipse snippet
+
+        Args:
+            cmd_call - a string with the call, e.g. "eclipse.run_python"
+            section_type - either "dependencies" or "run"
+
+        Returns:
+            Section (a dict), if found, otherwise None."""
+
+        section = None
+        call_parts = cmd_call.split('.')
+        section_name = call_parts[1] if len(call_parts) > 1 else section_type
+
+        if call_parts[0] == 'self':
+            section = getattr(self, '_' + section_name, None)
+        else:
+            snippet = yaml_snippet_loader.YamlSnippetLoader.get_snippet_by_name(call_parts[0])
+            if section_type == 'run':
+                section = snippet.get_run_section(section_name) if snippet else None
+            else:
+                section = snippet.get_dependencies_section(section_name) if snippet else None
+
+        return section
 
     def _get_section_to_run(self, section, kwargs_override=False, **kwargs):
         """Returns the proper section to run.
@@ -183,48 +252,53 @@ class YamlAssistant(assistant_base.AssistantBase):
             logger.debug('Couldn\'t find section {0} or any other appropriate.'.format(section))
         return to_run
 
-    def _get_snippet_and_section_name(self, snippet_call, **kwargs):
-        # if there is parenthesis, then snippet is being called with argument
-        snippet_tuple = snippet_call.split('(')
-        snippet = yaml_snippet_loader.YamlSnippetLoader.get_snippet_by_name(snippet_tuple[0])
-        section_name = snippet_tuple[1].strip(')') if len(snippet_tuple) > 1 else ''
-        return (snippet, section_name)
-
     def _assign_variable(self, variable, comm, kwargs):
         """Assigns value of another variable or result of command to given variable.
         The result is then put into kwargs (overwriting original value, if already there).
         Note, that unlike other methods, this method has to accept kwargs, not **kwargs.
 
-        If comm evaluates to something that is false, empty string is assigned to variable.
+        Cl commands store both stdout and stderr (as a single string) as the variable value.
+
+        Even if comm evaluates to something that is false, output is still stored and
+        this method doesn't fail.
 
         Args:
             variable: variable to assign to
             comm: either another variable or command to run
         """
         var_name = self._get_var_name(variable)
-        kwargs[var_name] = self._evaluate(comm, **kwargs) or ''
+        kwargs[var_name] = self._evaluate(comm, **kwargs)[1]
 
     def _get_var_name(self, dolar_variable):
-        name = dolar_variable.strip()[1:]
+        name = dolar_variable.strip()
+        name = name.strip('"')[1:]
         return name.strip('{}')
 
     def _evaluate(self, expression, **kwargs):
-        result = True
-        invert_result = False
+        # was command successful?
+        success = True
+        # command output
+        output = ''
+        invert_success = False
         expr = expression.strip()
         if expr.startswith('not '):
-            invert_result = True
+            invert_success = True
             expr = expr[4:]
 
-        if expr.startswith('$'):
+        if expr.startswith('$') or expr.startswith('"$'):
             var_name = self._get_var_name(expr)
-            result = kwargs.get(var_name, False)
+            if var_name in kwargs and kwargs[var_name]:
+                success = True
+                output = kwargs[var_name]
+            else:
+                success = False
         elif expr.startswith('defined '):
-            result = self._get_var_name(expr[8:]) in kwargs
+            success = self._get_var_name(expr[8:]) in kwargs
         else:
             try:
-                result = run_command('cl_n', CommandFormatter.format(expr, self.template_dir, self._files, **kwargs), **kwargs)
-            except exceptions.RunException:
-                result = False
+                output = run_command('cl_n', CommandFormatter.format('cl', expr, self.template_dir, self._files, **kwargs), **kwargs)
+            except exceptions.RunException as ex:
+                success = False
+                output = ex.output 
 
-        return result if not invert_result else not result
+        return (success if not invert_success else not success, output)
