@@ -9,9 +9,8 @@ from devassistant import path_runner
 class CliRunner(object):
     @classmethod
     def register_console_logging_handler(cls):
-        console_handler = logging.StreamHandler(stream=sys.stdout)
-        console_formatter = logging.Formatter('%(levelname)s - %(message)s')
-        console_handler.setFormatter(console_formatter)
+        console_handler = logging.StreamHandler(sys.stdout)
+        console_handler.setFormatter(logger.DevassistantClFormatter())
         console_handler.setLevel(logging.INFO)
         logger.logger.addHandler(console_handler)
 
@@ -26,4 +25,4 @@ class CliRunner(object):
             pr.run()
         except exceptions.ExecutionException as ex:
             # error is already logged, just catch it and silently exit here
-            pass
+            sys.exit(1)
