@@ -1,13 +1,3 @@
-class ClException(BaseException):
-    def __init__(self, command, returncode, stdout, stderr):
-        self.command = command
-        self.returncode = returncode
-        self.stdout = stdout
-        self.stderr = stderr
-
-    def __str__(self):
-        return self.stderr
-
 class ExecutionException(BaseException):
     pass
 
@@ -16,3 +6,15 @@ class DependencyException(ExecutionException):
 
 class RunException(ExecutionException):
     pass
+
+class ClException(RunException):
+    def __init__(self, command, returncode, output):
+        self.command = command
+        self.returncode = returncode
+        self.output = output
+
+    def __str__(self):
+        return self.output
+
+class AssistantNotFoundException(BaseException):
+    pass
