@@ -6,11 +6,11 @@ from devassistant import yaml_snippet_loader
 from devassistant.assistants import yaml_assistant
 
 class YamlAssistantLoader(object):
-    assistants_dirs = [os.path.join(os.path.dirname(__file__), 'assistants', 'yaml')]
+    assistants_dirs = [os.path.join(os.path.dirname(__file__), 'assistants', 'assistants')]
     _classes = []
 
     @classmethod
-    def get_top_level_assistants(cls, roles=['creator', 'modifier']):
+    def get_top_level_assistants(cls, roles=['creator', 'modifier', 'preparer']):
         assistants = cls.get_all_classes()
         are_subassistants = set()
         for a in assistants:
