@@ -57,6 +57,16 @@ class TestYamlAssistant(object):
         flexmock(RPMHelper).should_receive('was_rpm_installed').and_return(True)
         self.ya.dependencies()
 
+    def test_dependencies_if(self):
+        self.ya._dependencies = [{'if $x': [{'rpm': ['foo']}]}, {'else': [{'rpm': ['bar']}]}]
+        flexmock(RPMHelper).should_receive('is_rpm_installed').with_args('foo').and_return(True)
+        self.ya.dependencies(x='x')
+
+    def test_dependencies_else(self):
+        self.ya._dependencies = [{'if $x': [{'rpm': ['foo']}]}, {'else': [{'rpm': ['bar']}]}]
+        flexmock(RPMHelper).should_receive('is_rpm_installed').with_args('bar').and_return(True)
+        self.ya.dependencies()
+
     def test_run_pass(self):
         self.ya._run = [{'cl': 'true'}, {'cl': 'ls'}]
         self.ya.run()
@@ -89,21 +99,17 @@ class TestYamlAssistant(object):
         section = self.ya._get_section_to_run(section='run', kwargs_override=True, foo=None)
         assert section is self.ya._run_foo
 
-    def test_run_runs_in_foreground_if_asked(self):
-        self.ya._run = [{'cl_f': 'ls'}]
-        flexmock(ClHelper).should_receive('run_command').with_args('ls', True, logging.DEBUG)
-        self.ya.run(foo='bar')
-
     def test_run_logs_command_at_debug(self):
         # previously, this test used 'ls', but that is in different locations on different
         # distributions (due to Fedora's usrmove), so use something that should be common
         self.ya._run = [{'cl': 'id'}]
         self.ya.run(foo='bar')
-        assert ('DEBUG', settings.COMMAND_LOG_STRING.format(cmd='id')) in self.tlh.msgs
+        assert ('DEBUG', 'id') in self.tlh.msgs
+
     def test_run_logs_command_at_info_if_asked(self):
         self.ya._run = [{'cl_i': 'id'}]
         self.ya.run(foo='bar')
-        assert ('INFO', settings.COMMAND_LOG_STRING.format(cmd='id')) in self.tlh.msgs
+        assert ('INFO', 'id') in self.tlh.msgs
 
     def test_log(self):
         self.ya._run = [{'log_w': 'foo!'}]
@@ -157,7 +163,7 @@ class TestYamlAssistant(object):
     def test_assign_variable_from_unsuccessful_command(self):
         self.ya._run = [{'$foo': 'ls spam/spam/spam'}, {'log_i': '$foo'}]
         self.ya.run()
-        assert ('INFO', '') in self.tlh.msgs
+        assert ('INFO', u'ls: cannot access spam/spam/spam: No such file or directory') in self.tlh.msgs
 
     def test_assign_variable_in_condition_modifies_outer_scope(self):
         self.ya._run = [{'if $foo': [{'$foo': '$spam'}]}, {'log_i': '$foo'}]
@@ -165,14 +171,14 @@ class TestYamlAssistant(object):
         assert('INFO', 'spam') in self.tlh.msgs
 
     def test_assign_variable_in_snippet_or_run_doesnt_modify_outer_scope(self):
-        self.ya._run = [{'run': 'run_blah'}, {'log_i': '$foo'}]
+        self.ya._run = [{'call': 'self.run_blah'}, {'log_i': '$foo'}]
         self.ya._run_blah = [{'$foo': '$spam'}, {'log_i': 'yes, I ran'}]
         self.ya.run(foo='foo', spam='spam')
         assert('INFO', 'yes, I ran') in self.tlh.msgs
         assert('INFO', 'foo') in self.tlh.msgs
 
     def test_run_snippet(self):
-        self.ya._run = [{'snippet': 'mysnippet'}]
+        self.ya._run = [{'call': 'mysnippet'}]
         flexmock(YamlSnippetLoader).should_receive('get_snippet_by_name').\
                                     with_args('mysnippet').\
                                     and_return(snippet.Snippet('mysnippet.yaml', {'run': [{'log_i': 'spam'}]}))
@@ -180,7 +186,7 @@ class TestYamlAssistant(object):
         assert ('INFO', 'spam') in self.tlh.msgs
 
     def test_run_non_default_snippet_section(self):
-        self.ya._run = [{'snippet': 'mysnippet(run_foo)'}]
+        self.ya._run = [{'call': 'mysnippet.run_foo'}]
         flexmock(YamlSnippetLoader).should_receive('get_snippet_by_name').\
                                     with_args('mysnippet').\
                                     and_return(snippet.Snippet('mysnippet.yaml', {'run': [{'log_i': 'spam'}],
@@ -189,7 +195,7 @@ class TestYamlAssistant(object):
         assert ('INFO', 'foo') in self.tlh.msgs
 
     def test_dependencies_snippet(self):
-        self.ya._dependencies = [{'snippet': 'mysnippet(dependencies_foo)'}]
+        self.ya._dependencies = [{'call': 'mysnippet.dependencies_foo'}]
         flexmock(YamlSnippetLoader).should_receive('get_snippet_by_name').\
                                     with_args('mysnippet').\
                                     and_return(snippet.Snippet('mysnippet.yaml',
@@ -198,7 +204,7 @@ class TestYamlAssistant(object):
         self.ya.dependencies()
 
     def test_dependencies_snippet_also_installs_default_dependencies(self):
-        self.ya._dependencies = [{'snippet': 'mysnippet(dependencies_foo)'}]
+        self.ya._dependencies = [{'call': 'mysnippet.dependencies_foo'}]
         flexmock(YamlSnippetLoader).should_receive('get_snippet_by_name').\
                                     with_args('mysnippet').\
                                     and_return(snippet.Snippet('mysnippet.yaml',
@@ -209,7 +215,7 @@ class TestYamlAssistant(object):
         self.ya.dependencies()
 
     def test_snippet_uses_its_own_files_section(self):
-        self.ya._run = [{'snippet': 'mysnippet'}, {'log_w': '*first'}]
+        self.ya._run = [{'call': 'mysnippet'}, {'log_w': '*first'}]
         flexmock(YamlSnippetLoader).should_receive('get_snippet_by_name').\
                                     with_args('mysnippet').\
                                     and_return(snippet.Snippet('mysnippet.yaml',
@@ -220,6 +226,11 @@ class TestYamlAssistant(object):
         # make sure that after the snippet ends, we use the old files section
         assert filter(lambda x: x[0] == 'WARNING' and x[1].endswith('f/g'), self.tlh.msgs)
 
+    def test_scl_passes_scls_list_to_command_invocation(self):
+        # please don't use $__scls__ in actual assistants :)
+        self.ya._run = [{'scl enable foo bar': [{'log_i': '$__scls__'}]}]
+        self.ya.run()
+        assert ('INFO', "[['enable', 'foo', 'bar']]") in self.tlh.msgs
 
 class TestYamlAssistantModifier(object):
     template_dir = yaml_assistant.YamlAssistant.template_dir
